==> qtstalker_0.26.orig.tar.gz: qtstalker-0.26/src/Qtstalker.h <==
/***************************************************************************
                          qtstalker.h  -  description
                             -------------------
    begin                : Thu Mar  7 22:43:41 EST 2002
    copyright            : (C) 2001-2004 by Stefan Stratigakos
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QTSTALKER_H
#define QTSTALKER_H

#include <qmainwindow.h>
#include <qaction.h>
#include <qmenubar.h>
#include <qtoolbar.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qcombobox.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qtabwidget.h>
#include <qsplitter.h>
#include <qtoolbutton.h>
#include <qptrlist.h>
#include <qmultilineedit.h>

#include "Indicator.h"
#include "Plot.h"
#include "Config.h"
#include "Navigator.h"
#include "Setting.h"
#include "ChartPage.h"
#include "ChartDb.h"
#include "ChartObject.h"
#include "IndicatorTab.h"
#include "NavigatorTab.h"

#define DEFAULT_INDICATOR_HEIGHT 125

class QtstalkerApp : public QMainWindow
{
  Q_OBJECT
  
  signals:
    void signalGrid (bool);
    void signalScaleToScreen (bool);
    void signalPixelspace (int);
    void signalBackgroundColor (QColor);
    void signalBorderColor (QColor);
    void signalGridColor (QColor);
    void signalPlotFont (QFont);
    void signalIndex (int);
    void signalInterval(ChartDb::BarCompression);
    void signalIndicatorPageRefresh ();
    void signalPlotDate (bool);
    void signalChartPath (QString);
    void signalDrawMode (bool);
    void signalCrosshairsStatus(bool);

  public:

    enum chartStatus
    {
      None,
      Chart
    };

    QtstalkerApp ();
    ~QtstalkerApp ();
    void initConfig ();
    void initActions ();
    void initMenuBar ();
    void initToolBar ();
    void initGroupNav ();
    void initChartNav ();
    void initPortfolioNav();
    void initTestNav();
    void initIndicatorNav ();
    void initScannerNav ();
    QString getWindowCaption ();
    void setChartType (int);
    void loadChart (QString);
    void compressionChanged ();
    void addIndicatorButton (QString, bool);
    void exportChart (QString);
    void traverse(QString);
    void loadIndicator (Indicator *);
    void setSliderStart ();

  public slots:

    void slotAbout ();
    void slotQuit();
    void slotOpenChart (QString);
    void slotQuotes ();
    void slotOptions ();
    void slotDataWindow ();
    void slotNewIndicator ();
    void slotEditIndicator (QString, Plot *);
    void slotDeleteIndicator (QString, Plot *);
    void slotGrid (bool);
    void slotCompressionChanged (int);
    void slotChartTypeChanged (int);
    void slotSliderChanged (int);
    void slotPixelspaceChanged (int);
    void slotScaleToScreen (bool);
    void slotChartUpdated ();
    void slotStatusMessage (QString);
    void slotTabChanged (QWidget *);
    void slotHideNav (bool);
    void slotUpdateInfo (Setting *);
    void slotLogScale (bool);
    void slotHideMainPlot (bool);
    void slotPlotDate (bool);
    void slotPlotLeftMouseButton (int, int, bool);
    void slotPlotKeyPressed (QKeyEvent *);
    void slotDrawMode (bool);
    void slotMinPixelspaceChanged (int);
    void slotCrosshairsStatus (bool);
    void slotNavigatorPosition (int);
    void slotMainPlotFocus ();
    void slotTabIndicatorFocus ();

  private:
    QPopupMenu *fileMenu;
    QPopupMenu *editMenu;
    QPopupMenu *viewMenu;
    QPopupMenu *toolMenu;
    QPopupMenu *helpMenu;

    QAction *actionQuit;
    QAction *actionAbout;
    QAction *actionOptions;
    QAction *actionGrid;
    QAction *actionDatawindow;
    QAction *actionNewIndicator;
    QAction *actionQuotes;
    QAction *actionScaleToScreen;
    QAction *actionNav;
    QAction *actionLogScale;
    QAction *actionHideMainPlot;
    QAction *actionPlotDate;
    QAction *actionDrawMode;
    QAction *actionPlotFocus;
    QAction *actionTabIndicatorFocus;
    
    QToolBar *toolbar;
    QToolBar *toolbar2;
    QMenuBar *menubar;
    QSplitter *split;
    QSplitter *navSplitter;
    IndicatorTab *tabs;
    NavigatorTab *navTab;
    QWidget *baseWidget;
    QWidget *navBase;
    ChartPage *chartNav;
    Plot *mainPlot;
    QDict<Plot> plotList;
    QSpinBox *barCount;
    QComboBox *compressionCombo;
    QComboBox *chartTypeCombo;
    QSpinBox *pixelspace;
    Config *config;
    QSlider *slider;
    chartStatus status;
    QString chartPath;
    QString chartName;
    QString chartType;
    QString chartSymbol;
    BarData *recordList;
    QMultiLineEdit *infoLabel;
};

#endif

==> qtstalker-0.36.tar.gz: qtstalker-0.36/src/Qtstalker.h <==
/***************************************************************************
                          qtstalker.h  -  description
                             -------------------
    begin                : Thu Mar  7 22:43:41 EST 2002
    copyright            : (C) 2001-2007 by Stefan Stratigakos
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QTSTALKER_H
#define QTSTALKER_H

#include <qmainwindow.h>
#include <qmenubar.h>
#include <qtoolbar.h>
#include <qstring.h>
#include <qtabwidget.h>
#include <qsplitter.h>
#include <qmultilineedit.h>
#include <qdict.h>
#include <qprogressbar.h>
#include <qstatusbar.h>
#include <qtabwidget.h>

#include "Indicator.h"
#include "Plot.h"
#include "Config.h"
#include "Navigator.h"
#include "Setting.h"
#include "ChartPage.h"
#include "NavigatorTab.h"
#include "IndicatorPage.h"
#include "ScannerPage.h"
#include "PortfolioPage.h"
#include "TestPage.h"
#include "GroupPage.h"
#include "ChartToolbar.h"
#include "MainMenubar.h"
#include "ExtraToolbar.h"
#include "DBIndex.h"
#include "RcFile.h"

// not used #define DEFAULT_INDICATOR_HEIGHT 125

class QtstalkerApp : public QMainWindow
{
  Q_OBJECT
  
  signals:
    void signalPixelspace (int);
    void signalBackgroundColor (QColor);
    void signalBorderColor (QColor);
    void signalGridColor (QColor);
    void signalPlotFont (QFont);
    void signalIndex (int);
    void signalInterval(BarData::BarLength);
    void signalChartPath (QString);
    void signalCrosshairsStatus(bool);

  public:

    enum chartStatus
    {
      None,
      Chart
    };

    QtstalkerApp ();
    ~QtstalkerApp ();
    void initConfig ();
    void initMenuBar ();
    void initToolBar ();
    void initGroupNav ();
    void initChartNav ();
    void initPortfolioNav();
    void initTestNav();
    void initIndicatorNav ();
    void initScannerNav ();
    QString getWindowCaption ();
    void loadChart (QString &);
    void barLengthChanged ();
    void exportChart (QString &);
    void traverse(QString &);
    void loadIndicator (Indicator *);
    void setSliderStart ();

  public slots:
    void slotAbout ();
    void slotQuit();
    void slotOpenChart (QString);
    void slotQuotes ();
    void slotOptions ();
    void slotDataWindow ();
    void slotNewIndicator (Indicator *);
    void slotEditIndicator (Indicator *);
    void slotDeleteIndicator (QString);
    void slotBarLengthChanged (int);
    void slotPixelspaceChanged (int);
    void slotChartUpdated ();
    void slotStatusMessage (QString);
    void slotHideNav (bool);
    void slotUpdateInfo (Setting *);
    void slotPlotLeftMouseButton (int, int, bool);
    void slotCrosshairsStatus (bool);
    void slotNavigatorPosition (int);
    void slotHelp ();
    void slotDisableIndicator (QString);
    void slotEnableIndicator (QString);
    void slotProgMessage (int, int);
    void slotDrawPlots ();
    void slotPaperTradeChanged (bool);
    void addIndicatorButton (QString);
    void slotWakeup ();
    void slotIndicatorSummary ();
    void slotDeleteAllCO ();
    void slotDeleteCO (QString);
    void slotSaveCO (Setting);
    void slotMenubarStatus (bool);
    void slotExtraToolbarStatus (bool);
    void slotAppFont (QFont);
    void slotLoadMainToolbarSettings();
    void slotSavePlotSizes();
    void slotLoadPlotSizes();
    
  private:
    QToolBar *toolbar;
    ChartToolbar *toolbar2;
    ExtraToolbar *extraToolbar;
    MainMenubar *menubar;
    QSplitter *split;
    QSplitter *navSplitter;
    QSplitter *dpSplitter;
    NavigatorTab *navTab;
    QWidget *baseWidget;
    QWidget *navBase;
    ChartPage *chartNav;
    QDict<Plot> plotList;
    Config config;
    chartStatus status;
    QString chartPath;
    QString chartName;
    QString chartSymbol;
    QString dbPlugin;
    BarData *recordList;
    QMultiLineEdit *infoLabel;
    IndicatorPage *ip;
    PortfolioPage *pp;
    ScannerPage *sp;
    TestPage *tp;
    GroupPage *gp;
    QProgressBar *progBar;
    QStatusBar *statusbar;
    QString chartType;
    QPtrList<QTabWidget> tabList;
    QDict<QWidget> widgetList;
    DBIndex *chartIndex;
    RcFile rcfile;
    QString lastIndicatorUsed1;
    QString lastIndicatorUsed2;
    QString lastIndicatorUsed3;
};

#endif
